@@ -10,9 +10,10 @@ from tqdm import tqdm
 def start_session(reg, pro):
     started = False
     # profile selection input loop, lets you type in your aws credentials profile and starts a session.
-    print(f"Starting AWS session in {reg} for profile {pro}...")
+    print(f"Starting AWS session in {reg}...")
     while not started:
         if not os.getenv('AWS_DEFAULT_PROFILE'):
+            print('No default profile found...')
             try:
                 print("Trying environment variables...")
                 ACCESS_KEY = os.getenv('AWS_ACCESS_KEY_ID')
@@ -21,13 +22,15 @@ def start_session(reg, pro):
                 s = boto3.Session(
                     aws_access_key_id=ACCESS_KEY,
                     aws_secret_access_key=SECRET_KEY,
-                    aws_session_token=SESSION_TOKEN
+                    aws_session_token=SESSION_TOKEN,
+                    region_name=reg
                 )
                 return s
             except botocore.exceptions.ClientError as error:
                 print('Invalid profile: {}'.format(pro))
                 raise error
         else:
+            print(f'Trying profile {pro}...')
             try:
                 s = boto3.Session(profile_name=pro, region_name=reg)
                 if s:
@@ -68,7 +71,7 @@ def cli(region, profile, csv):
     files = [f for f in os.listdir(path) if os.path.isfile(f)]
     print(files)
     if csv not in files:
-        print(f'File {csv} not found. Exiting...')
+        print(f'File {csv} not found in working directory. Exiting...')
         exit()
 
     try:
@@ -94,7 +97,11 @@ def cli(region, profile, csv):
 
     ssm_client = session.client('ssm')
     paginator = ssm_client.get_paginator('describe_parameters')
-    response_iterator = paginator.paginate()
+    try:
+        response_iterator = paginator.paginate()
+    except botocore.exceptions.ClientError as e:
+        print(e)
+        exit(1)
 
     existing_params = []
     duplicated_params = []
@@ -142,9 +149,9 @@ def cli(region, profile, csv):
             error_codes.append(e)
 
     if failed_params:
-        print(f'{len(failed_params)} parameters could not be created:')
+        print(f'{len(failed_params)} parameter(s) could not be created:')
         for x in range(len(failed_params)):
             print(f'\t- {failed_params[x]}: {error_codes[x]}')
 
     print('Parameter creation complete.')
-    print(f'{len(successful_params)} parameters were created.')
+    print(f'{len(successful_params)} parameter(s) were created.')
